# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: place_tag/grpc/place_tag.proto
# Protobuf Python Version: 4.25.1
# pylint: skip-file
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eplace_tag/grpc/place_tag.proto\x12\x10\x63onfig.place_tag\x1a\x1cgoogle/protobuf/struct.proto"k\n\x0e\x43ontentRequest\x12\r\n\x05place\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x12\n\x05order\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x0e\n\x06header\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\tB\x08\n\x06_order"W\n\x0f\x43ontentResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"2\n\x14\x43ontentSearchRequest\x12\r\n\x05place\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t"X\n\x0cMediaRequest\x12\r\n\x05place\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x12\n\nmedia_type\x18\x03 \x01(\t\x12\x18\n\x10media_identifier\x18\x04 \x01(\t"U\n\rMediaResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"0\n\x12MediaSearchRequest\x12\r\n\x05place\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t"\xbb\x03\n\nSeoRequest\x12\r\n\x05place\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x12\n\x05title\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x15\n\rcanonical_tag\x18\x07 \x01(\t\x12\x18\n\x10meta_description\x18\x08 \x01(\t\x12\x33\n\rmeta_keywords\x18\t \x01(\x0b\x32\x17.google.protobuf.StructH\x01\x88\x01\x01\x12\x10\n\x08no_index\x18\x0f \x01(\x08\x12\x12\n\npage_title\x18\x10 \x01(\t\x12\'\n\x1apage_icon_media_identifier\x18\x11 \x01(\tH\x02\x88\x01\x01\x12\x11\n\tno_follow\x18\x13 \x01(\x08\x12\x16\n\x0eog_image_width\x18\x15 \x01(\x05\x12\x17\n\x0fog_image_height\x18\x16 \x01(\x05\x12!\n\x19og_image_media_identifier\x18\x17 \x01(\t\x12\x17\n\nfront_path\x18\x18 \x01(\tH\x03\x88\x01\x01\x42\x08\n\x06_titleB\x10\n\x0e_meta_keywordsB\x1d\n\x1b_page_icon_media_identifierB\r\n\x0b_front_path"S\n\x0bSeoResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct".\n\x10SeoSearchRequest\x12\r\n\x05place\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t" \n\x0eSitemapRequest\x12\x0e\n\x06\x65ntity\x18\x01 \x01(\t"W\n\x0fSitemapResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct2\xbb\x01\n\x11\x43ontentController\x12O\n\x06\x43reate\x12 .config.place_tag.ContentRequest\x1a!.config.place_tag.ContentResponse"\x00\x12U\n\x06Search\x12&.config.place_tag.ContentSearchRequest\x1a!.config.place_tag.ContentResponse"\x00\x32\xb1\x01\n\x0fMediaController\x12K\n\x06\x43reate\x12\x1e.config.place_tag.MediaRequest\x1a\x1f.config.place_tag.MediaResponse"\x00\x12Q\n\x06Search\x12$.config.place_tag.MediaSearchRequest\x1a\x1f.config.place_tag.MediaResponse"\x00\x32\xfc\x01\n\rSeoController\x12G\n\x06\x43reate\x12\x1c.config.place_tag.SeoRequest\x1a\x1d.config.place_tag.SeoResponse"\x00\x12S\n\nGetSitemap\x12 .config.place_tag.SitemapRequest\x1a!.config.place_tag.SitemapResponse"\x00\x12M\n\x06Search\x12".config.place_tag.SeoSearchRequest\x1a\x1d.config.place_tag.SeoResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "place_tag.grpc.place_tag_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_CONTENTREQUEST"]._serialized_start = 82
    _globals["_CONTENTREQUEST"]._serialized_end = 189
    _globals["_CONTENTRESPONSE"]._serialized_start = 191
    _globals["_CONTENTRESPONSE"]._serialized_end = 278
    _globals["_CONTENTSEARCHREQUEST"]._serialized_start = 280
    _globals["_CONTENTSEARCHREQUEST"]._serialized_end = 330
    _globals["_MEDIAREQUEST"]._serialized_start = 332
    _globals["_MEDIAREQUEST"]._serialized_end = 420
    _globals["_MEDIARESPONSE"]._serialized_start = 422
    _globals["_MEDIARESPONSE"]._serialized_end = 507
    _globals["_MEDIASEARCHREQUEST"]._serialized_start = 509
    _globals["_MEDIASEARCHREQUEST"]._serialized_end = 557
    _globals["_SEOREQUEST"]._serialized_start = 560
    _globals["_SEOREQUEST"]._serialized_end = 1003
    _globals["_SEORESPONSE"]._serialized_start = 1005
    _globals["_SEORESPONSE"]._serialized_end = 1088
    _globals["_SEOSEARCHREQUEST"]._serialized_start = 1090
    _globals["_SEOSEARCHREQUEST"]._serialized_end = 1136
    _globals["_SITEMAPREQUEST"]._serialized_start = 1138
    _globals["_SITEMAPREQUEST"]._serialized_end = 1170
    _globals["_SITEMAPRESPONSE"]._serialized_start = 1172
    _globals["_SITEMAPRESPONSE"]._serialized_end = 1259
    _globals["_CONTENTCONTROLLER"]._serialized_start = 1262
    _globals["_CONTENTCONTROLLER"]._serialized_end = 1449
    _globals["_MEDIACONTROLLER"]._serialized_start = 1452
    _globals["_MEDIACONTROLLER"]._serialized_end = 1629
    _globals["_SEOCONTROLLER"]._serialized_start = 1632
    _globals["_SEOCONTROLLER"]._serialized_end = 1884
# @@protoc_insertion_point(module_scope)
