from .grpc_lib.place_tag_pb2 import (
    ContentRequest,
    MediaRequest,
    SeoRequest,
    SeoSearchRequest,
    SitemapRequest,
)
from .grpc_lib.place_tag_pb2_grpc import (
    ContentControllerStub,
    MediaControllerStub,
    SeoControllerStub,
)

SUCCESS_CODE = "0"


class RequestMessages:
    ADD_MEDIA = MediaRequest
    ADD_CONTENT = ContentRequest
    ADD_SEO = SeoRequest
    SITEMAP = SitemapRequest
    # search messages are all the same so we use one
    SEARCH = SeoSearchRequest


class RPCMethodNames:
    CREATE = "Create"
    SEARCH = "Search"
    GET_SITEMAP = "GetSitemap"


class ControllerStubs:
    MEDIA = MediaControllerStub()
    CONTENT = ContentControllerStub()
    SEO = SeoControllerStub()


class Entities:
    COURSE = "course"
    LESSON = "lesson"
    MASTER_COURSE = "master_course"
    BLOG = "blog"
