# pylint: skip-file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc
from . import place_tag_pb2 as place__tag_dot_grpc_dot_place__tag__pb2


class ContentControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel=None):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.channel = channel
        self.ready()

    def ready(self):
        if self.channel is not None:
            self.Create = self.channel.unary_unary(
                "/config.place_tag.ContentController/Create",
                request_serializer=place__tag_dot_grpc_dot_place__tag__pb2.ContentRequest.SerializeToString,
                response_deserializer=place__tag_dot_grpc_dot_place__tag__pb2.ContentResponse.FromString,
            )
            self.Search = self.channel.unary_unary(
                "/config.place_tag.ContentController/Search",
                request_serializer=place__tag_dot_grpc_dot_place__tag__pb2.ContentSearchRequest.SerializeToString,
                response_deserializer=place__tag_dot_grpc_dot_place__tag__pb2.ContentResponse.FromString,
            )


class ContentControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Search(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ContentControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Create": grpc.unary_unary_rpc_method_handler(
            servicer.Create,
            request_deserializer=place__tag_dot_grpc_dot_place__tag__pb2.ContentRequest.FromString,
            response_serializer=place__tag_dot_grpc_dot_place__tag__pb2.ContentResponse.SerializeToString,
        ),
        "Search": grpc.unary_unary_rpc_method_handler(
            servicer.Search,
            request_deserializer=place__tag_dot_grpc_dot_place__tag__pb2.ContentSearchRequest.FromString,
            response_serializer=place__tag_dot_grpc_dot_place__tag__pb2.ContentResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "config.place_tag.ContentController", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class ContentController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.place_tag.ContentController/Create",
            place__tag_dot_grpc_dot_place__tag__pb2.ContentRequest.SerializeToString,
            place__tag_dot_grpc_dot_place__tag__pb2.ContentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Search(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.place_tag.ContentController/Search",
            place__tag_dot_grpc_dot_place__tag__pb2.ContentSearchRequest.SerializeToString,
            place__tag_dot_grpc_dot_place__tag__pb2.ContentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )


class MediaControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel=None):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.channel = channel
        self.ready()

    def ready(self):
        if self.channel is not None:
            self.Create = self.channel.unary_unary(
                "/config.place_tag.MediaController/Create",
                request_serializer=place__tag_dot_grpc_dot_place__tag__pb2.MediaRequest.SerializeToString,
                response_deserializer=place__tag_dot_grpc_dot_place__tag__pb2.MediaResponse.FromString,
            )
            self.Search = self.channel.unary_unary(
                "/config.place_tag.MediaController/Search",
                request_serializer=place__tag_dot_grpc_dot_place__tag__pb2.MediaSearchRequest.SerializeToString,
                response_deserializer=place__tag_dot_grpc_dot_place__tag__pb2.MediaResponse.FromString,
            )


class MediaControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Search(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_MediaControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Create": grpc.unary_unary_rpc_method_handler(
            servicer.Create,
            request_deserializer=place__tag_dot_grpc_dot_place__tag__pb2.MediaRequest.FromString,
            response_serializer=place__tag_dot_grpc_dot_place__tag__pb2.MediaResponse.SerializeToString,
        ),
        "Search": grpc.unary_unary_rpc_method_handler(
            servicer.Search,
            request_deserializer=place__tag_dot_grpc_dot_place__tag__pb2.MediaSearchRequest.FromString,
            response_serializer=place__tag_dot_grpc_dot_place__tag__pb2.MediaResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "config.place_tag.MediaController", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class MediaController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.place_tag.MediaController/Create",
            place__tag_dot_grpc_dot_place__tag__pb2.MediaRequest.SerializeToString,
            place__tag_dot_grpc_dot_place__tag__pb2.MediaResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Search(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.place_tag.MediaController/Search",
            place__tag_dot_grpc_dot_place__tag__pb2.MediaSearchRequest.SerializeToString,
            place__tag_dot_grpc_dot_place__tag__pb2.MediaResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )


class SeoControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel=None):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.channel = channel
        self.ready()

    def ready(self):
        if self.channel is not None:
            self.Create = self.channel.unary_unary(
                "/config.place_tag.SeoController/Create",
                request_serializer=place__tag_dot_grpc_dot_place__tag__pb2.SeoRequest.SerializeToString,
                response_deserializer=place__tag_dot_grpc_dot_place__tag__pb2.SeoResponse.FromString,
            )
            self.GetSitemap = self.channel.unary_unary(
                "/config.place_tag.SeoController/GetSitemap",
                request_serializer=place__tag_dot_grpc_dot_place__tag__pb2.SitemapRequest.SerializeToString,
                response_deserializer=place__tag_dot_grpc_dot_place__tag__pb2.SitemapResponse.FromString,
            )
            self.Search = self.channel.unary_unary(
                "/config.place_tag.SeoController/Search",
                request_serializer=place__tag_dot_grpc_dot_place__tag__pb2.SeoSearchRequest.SerializeToString,
                response_deserializer=place__tag_dot_grpc_dot_place__tag__pb2.SeoResponse.FromString,
            )


class SeoControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetSitemap(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Search(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_SeoControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Create": grpc.unary_unary_rpc_method_handler(
            servicer.Create,
            request_deserializer=place__tag_dot_grpc_dot_place__tag__pb2.SeoRequest.FromString,
            response_serializer=place__tag_dot_grpc_dot_place__tag__pb2.SeoResponse.SerializeToString,
        ),
        "GetSitemap": grpc.unary_unary_rpc_method_handler(
            servicer.GetSitemap,
            request_deserializer=place__tag_dot_grpc_dot_place__tag__pb2.SitemapRequest.FromString,
            response_serializer=place__tag_dot_grpc_dot_place__tag__pb2.SitemapResponse.SerializeToString,
        ),
        "Search": grpc.unary_unary_rpc_method_handler(
            servicer.Search,
            request_deserializer=place__tag_dot_grpc_dot_place__tag__pb2.SeoSearchRequest.FromString,
            response_serializer=place__tag_dot_grpc_dot_place__tag__pb2.SeoResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "config.place_tag.SeoController", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class SeoController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.place_tag.SeoController/Create",
            place__tag_dot_grpc_dot_place__tag__pb2.SeoRequest.SerializeToString,
            place__tag_dot_grpc_dot_place__tag__pb2.SeoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetSitemap(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.place_tag.SeoController/GetSitemap",
            place__tag_dot_grpc_dot_place__tag__pb2.SitemapRequest.SerializeToString,
            place__tag_dot_grpc_dot_place__tag__pb2.SitemapResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Search(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.place_tag.SeoController/Search",
            place__tag_dot_grpc_dot_place__tag__pb2.SeoSearchRequest.SerializeToString,
            place__tag_dot_grpc_dot_place__tag__pb2.SeoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
